llrqetag - Query information about energy policy tags

Use the llrqetag  command to display energy policy tags and the
information associated with them.


Syntax


llrqetag [-? | -H | -v | [-u user] [-j job] [-e energy_tag]]


Flags


-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-u user
   Displays energy policies that belong to this LoadLeveler user.

-j job
   Is a job or step identifier. When a job identifier is specified, the
   command action is taken for all steps of the job. 

   The format of a job identifier is host.jobid. The format of a step
   identifier is host.jobid.stepid.    

   where: 

   *  host is the name of the machine that assigned the job and step
      identifiers.

   *  jobid is the job number assigned to the job when it was submitted.

   *  stepid is the job step number assigned to the job step when it was
      submitted. The job or step identifier can be specified in an
      abbreviated form, jobid or jobid.stepid, when the command is
      invoked on the same machine that assigned the job and step
      identifiers. In this case, LoadLeveler will use the local
      machine's hostname to construct the full job or step identifier.

-e energy_tag
   Is an energy tag name of the form [user.]tag_name 

   where: 

   *  user is the user name who generated the energy tag.

   *  tag_name is the user-defined identifier in the job command file.


Description


The llrqetag  command queries information about the energy policies that
is saved in the database. When you issue this command, it displays all
the energy policies in the database that have been generated by the
user. For the root user, the command will display all the tag names in
the database.

The policy tag is a user-defined identifier of the job energy policy,
which is used to identify the estimated power consumed, the estimated
execution time of the job, and the job performance degradation. The
energy tag name is specified in the job command file and when you submit
a job, the energy tag name must be unique for each of your jobs.

This command is available only when the database-based configuration is
used by LoadLeveler.


Examples


1. To display the energy policy information for energy policy tag
   long_running_job, issue:

   llrqetag -e long_running_job

   You should receive a response similar to the following:
             Tag Name: long_running_job
         Generated by: c111bc4n13.ppd.pok.ibm.com.91.0
       Last used Time: Tue May 10 05:00:01 EDT 2011
                 User: userA
    Nominal Frequency: 3.3 GHZ
    Node's Energy Use: 0.8 Kwh
       Execution Time: 950 Seconds
   Frequency(GHZ) EstEnergyConsum(Kwh) EngSaving(%) EstTime(Seconds) PerfDeg(%)
             3.10                 0.75          6.2             1000        5.2
             2.80                 0.65         18.8             1050       10.5 
             2.60                 0.6          25.0             1100       15.8
             2.20                 0.5          37.5             1150       21.1                                                                          
  
   where: 

   Tag Name 
            Is the energy tag name.

   Generated by
            Is the job step identifier that generated the tag.

   Last used Time
            Is the time when the tag was last used.

   User:    Is the user who generated the tag.

   Nominal Frequency
            Is the CPU nominal frequency.

   Node's Energy Use
            Is the energy consumption per node of the job step at the
            nominal frequency.

   Execution Time
            Is the execution time of the job step at the nominal
            frequency.

   Frequency (GHZ) 
            Is the CPU frequency.

   EstEnergyConsum (KWH) 
             Is the estimated energy consumption of the job step at this
            frequency.

   EngSaving (%) 
            Is the percentage of energy savings at this frequency.

   EstTime (Seconds)
            Is the estimated run time of the job step at this frequency.

   PerfDeg (%)
            Is the percentage of the performance degradation at this
            frequency.

2. To display all energy policy information generated by userA, issue: 

   llrqetag -u userA

   You should receive a response similar to the following:
             Tag Name: long_running_job
         Generated by: c111bc4n13.ppd.pok.ibm.com.91.0
       Last used Time: Tue May 10 05:00:01 EDT 2011
                 User: userA
    Nominal Frequency: 3.3 GHZ
    Node's Energy Use: 0.8 Kwh
       Execution Time: 950 Seconds
   Frequency(GHZ) EstEnergyConsum(KWH) EngSaving(%) EstTime(Seconds) PerfDeg(%)
             3.10                 0.75          6.0             1000        5.0
             2.80                 0.65         19.0             1050       11.0 
     
  

   Note: The llrqetag  command will display the energy policies
   generated by the user who issues the command if the -u option is not
   specified.


Security


LoadLeveler administrators and users can issue this command.
